==> qore-1.16.1.tar.bz2: qore-1.16.1/cmake/unix-config.h.cmake <==


/* headers */
#cmakedefine HAVE_ARPA_INET_H
#cmakedefine HAVE_CXXABI_H
#cmakedefine HAVE_DLFCN_H
#cmakedefine HAVE_FCNTL_H
#cmakedefine HAVE_GETOPT_H
#cmakedefine HAVE_GLOB_H
#cmakedefine HAVE_GRP_H
#cmakedefine HAVE_ICONV_H
#cmakedefine HAVE_INTTYPES_H
#cmakedefine HAVE_MEMORY_H
#cmakedefine HAVE_NETDB_H
#cmakedefine HAVE_NETINET_IN_H
#cmakedefine HAVE_NETINET_TCP_H
#cmakedefine HAVE_POLL_H
#cmakedefine HAVE_PWD_H
#cmakedefine HAVE_STDBOOL_H
#cmakedefine HAVE_STDDEF_H
#cmakedefine HAVE_STDINT_H
#cmakedefine HAVE_STDLIB_H
#cmakedefine HAVE_STRINGS_H
#cmakedefine HAVE_STRING_H
#cmakedefine HAVE_SYS_SELECT_H
#cmakedefine HAVE_SYS_SOCKET_H
#cmakedefine HAVE_SYS_STATVFS_H
#cmakedefine HAVE_SYS_STAT_H
#cmakedefine HAVE_SYS_TIME_H
#cmakedefine HAVE_SYS_TYPES_H
#cmakedefine HAVE_SYS_UN_H
#cmakedefine HAVE_SYS_WAIT_H
#cmakedefine HAVE_TERMIOS_H
#cmakedefine HAVE_UMEM_H
#cmakedefine HAVE_UNISTD_H
#cmakedefine HAVE_VFORK_H
#cmakedefine HAVE_WINSOCK2_H
#cmakedefine HAVE_WS2TCPIP_H

/* functions */
#cmakedefine HAVE_ACCESS
#cmakedefine HAVE_ALARM
#cmakedefine HAVE_ATOLL
#cmakedefine HAVE_BZERO
#cmakedefine HAVE_CHOWN
#cmakedefine HAVE_CLOCK_GETTIME
#cmakedefine HAVE_DECL_STRERROR_R
#cmakedefine HAVE_DOPRNT
#cmakedefine HAVE_EXP2
#cmakedefine HAVE_FLOOR
#cmakedefine HAVE_FORK
#cmakedefine HAVE_FSYNC
#cmakedefine HAVE_GETEGID
#cmakedefine HAVE_GETEUID
#cmakedefine HAVE_GETGID
#cmakedefine HAVE_GETGRGID_R
#cmakedefine HAVE_GETGRNAM_R
#cmakedefine HAVE_GETGROUPS
#cmakedefine HAVE_GETHOSTBYADDR
#cmakedefine HAVE_GETHOSTBYADDR_R
#cmakedefine HAVE_GETHOSTBYNAME_R
#cmakedefine HAVE_GETHOSTBYNAME
#cmakedefine HAVE_GETHOSTNAME
#cmakedefine HAVE_GETPPID
#cmakedefine HAVE_GETPWNAM_R
#cmakedefine HAVE_GETPWUID_R
#cmakedefine HAVE_GETSOCKOPT
#cmakedefine HAVE_GETTIMEOFDAY
#cmakedefine HAVE_GETUID
#cmakedefine HAVE_GLOB
#cmakedefine HAVE_GMTIME_R
#cmakedefine HAVE_INET_NTOP
#cmakedefine HAVE_INET_PTON
#cmakedefine HAVE_ISBLANK
#cmakedefine HAVE_KILL
#cmakedefine HAVE_LCHOWN
#cmakedefine HAVE_LOCALTIME_R
#cmakedefine HAVE_LSTAT
#cmakedefine HAVE_MEMMEM
#cmakedefine HAVE_MEMMOVE
#cmakedefine HAVE_MEMSET
#cmakedefine HAVE_MKFIFO
#cmakedefine HAVE_MKFIFO
#cmakedefine HAVE_NANOSLEEP
#cmakedefine HAVE_POLL
#cmakedefine HAVE_PTHREAD_ATTR_GETSTACKSIZE
#cmakedefine QORE_HAVE_PTHREAD_SETNAME_NP_1
#cmakedefine QORE_HAVE_PTHREAD_SETNAME_NP_2
#cmakedefine QORE_HAVE_PTHREAD_SETNAME_NP_3
#cmakedefine QORE_HAVE_PTHREAD_SET_NAME_NP
#cmakedefine QORE_HAVE_PTHREAD_GETATTR_NP
#cmakedefine HAVE_PTHREAD_GETNAME_NP
#cmakedefine HAVE_PUTENV
#cmakedefine HAVE_RANDOM
#cmakedefine HAVE_READLINK
#cmakedefine HAVE_REALLOC
#cmakedefine HAVE_REALPATH
#cmakedefine HAVE_REGCOMP
#cmakedefine HAVE_ROUND
#cmakedefine HAVE_SELECT
#cmakedefine HAVE_SETEGID
#cmakedefine HAVE_SETEGID
#cmakedefine HAVE_SETENV
#cmakedefine HAVE_SETEUID
#cmakedefine HAVE_SETEUID
#cmakedefine HAVE_SETGID
#cmakedefine HAVE_SETGROUPS
#cmakedefine HAVE_SETSID
#cmakedefine HAVE_SETSOCKOPT
#cmakedefine HAVE_SETUID
#cmakedefine HAVE_SETUID
#cmakedefine HAVE_SLEEP
#cmakedefine HAVE_SOCKET
#cmakedefine HAVE_STRCASECMP
#cmakedefine HAVE_STRCASESTR
#cmakedefine HAVE_STRCHR
#cmakedefine HAVE_STRDUP
#cmakedefine HAVE_STRERROR
#cmakedefine HAVE_STRERROR_R
#cmakedefine HAVE_STRNCASECMP
#cmakedefine HAVE_STRSPN
#cmakedefine HAVE_STRSTR
#cmakedefine HAVE_STRTOIMAX
#cmakedefine HAVE_STRTOL
#cmakedefine HAVE_STRTOLL
#cmakedefine HAVE_SYMLINK
#cmakedefine HAVE_SYSTEM
#cmakedefine HAVE_TBBMALLOC
#cmakedefine HAVE_TIMEGM
#cmakedefine HAVE_UNSETENV
#cmakedefine HAVE_USLEEP
#cmakedefine HAVE_VFORK
#cmakedefine HAVE_VPRINTF
#cmakedefine HAVE_PTHREAD_GET_STACKSIZE_NP
#cmakedefine HAVE_GETIFADDRS
#cmakedefine HAVE_WORKING_FORK
#cmakedefine HAVE_WORKING_VFORK
#cmakedefine STRERROR_R_CHAR_P

/* OpenSSL */
#cmakedefine HAVE_OPENSSL_CONST
#cmakedefine HAVE_OPENSSL_HMAC_RV
#cmakedefine HAVE_OPENSSL_SHA512
#cmakedefine HAVE_OPENSSL_SHA
#cmakedefine HAVE_OPENSSL_MDC2
#cmakedefine NEED_SSL_CTX_NEW_CONST
#cmakedefine HAVE_X509_GET_SIGNATURE_NID
#cmakedefine HAVE_X509_GET0_SIGNATURE_CONST
#cmakedefine HAVE_X509_GET0_PUBKEY
#cmakedefine HAVE_OPENSSL_INIT_CRYPTO
#cmakedefine HAVE_SSL_SET_MAX_PROTO_VERSION
#cmakedefine HAVE_SSL_SET_HOSTFLAGS
#cmakedefine HAVE_SSL_SET1_HOST
#cmakedefine HAVE_EVP_MAC_CTX_NEW
#cmakedefine HAVE_SSL_READ_EX

/* mpfr */
#cmakedefine HAVE_MPFR_BUILDOPT_TLS_P
#cmakedefine HAVE_MPFR_DIVBY0
#cmakedefine HAVE_MPFR_EXP_T
#cmakedefine HAVE_MPFR_REGULAR
#cmakedefine HAVE_MPFR_RNDN
#cmakedefine HAVE_MPFR_SPRINTF
#cmakedefine HAVE_RNDN

/* backtrace */
#cmakedefine Backtrace_FOUND
#ifdef Backtrace_FOUND
#define HAVE_EXECINFO_H
#define HAVE_BACKTRACE
#endif

/* gethost* */
#cmakedefine HAVE_DECL_GETHOSTBYADDR_R
#cmakedefine HAVE_DECL_GETHOSTBYNAME_R
#cmakedefine HAVE_GETHOSTBYNAME_R_GLIBC2_STYLE
#cmakedefine HAVE_GETHOSTBYNAME_R_RETURN_INT
#cmakedefine HAVE_SOLARIS_STYLE_GETHOST

/* stl hash_map and list */
#cmakedefine HASH_MAP_INCLUDE @HASH_MAP_INCLUDE@
#cmakedefine HASH_NAMESPACE @HASH_NAMESPACE@
#cmakedefine HASH_SET_INCLUDE @HASH_SET_INCLUDE@
#cmakedefine HASH_TYPE @HASH_TYPE@
#cmakedefine HAVE_EXT_HASH_MAP
#cmakedefine HAVE_EXT_HASH_SET
#cmakedefine HAVE_EXT_SLIST
#cmakedefine HAVE_HASH_MAP
#cmakedefine HAVE_HASH_SET
#cmakedefine HAVE_QORE_HASH_MAP
#cmakedefine HAVE_QORE_SLIST
#cmakedefine HAVE_SLIST
#cmakedefine HAVE_UNORDERED_MAP
#cmakedefine LIST_NAMESPACE @LIST_NAMESPACE@
#cmakedefine LIST_SET_INCLUDE @LIST_SET_INCLUDE@
#cmakedefine SLIST_INCLUDE @SLIST_INCLUDE@
#cmakedefine SLIST_TYPE @SLIST_TYPE@

/* CPUs */
#cmakedefine CPU_X86_64
#cmakedefine SPARC

/* OSes */
#cmakedefine DARWIN
#cmakedefine HPUX
#cmakedefine SOLARIS

/* the rest */
#cmakedefine HAVE_ATOMIC_COMPILE_ONLY
#cmakedefine HAVE_CXX11
#cmakedefine HAVE_GCC_VISIBILITY
#cmakedefine HAVE_LIBATOMIC
#cmakedefine HAVE_LLVM_BUG_22050
#cmakedefine HAVE_LOCAL_VARIADIC_ARRAYS
#cmakedefine HAVE_LSTAT_EMPTY_STRING_BUG
#cmakedefine HAVE_NAMESPACES
#cmakedefine HAVE_PTHREAD
#cmakedefine HAVE_SIGNAL_HANDLING
#cmakedefine HAVE_STAT_EMPTY_STRING_BUG
#cmakedefine HAVE_STRUCT_FLOCK
#cmakedefine HAVE_STRUCT_STAT_ST_BLKSIZE
#cmakedefine HAVE_STRUCT_STAT_ST_BLOCKS
#cmakedefine HAVE_STRUCT_STAT_ST_RDEV
#cmakedefine HAVE_ST_BLOCKS
#cmakedefine NEED_DLFCN_WRAPPER
#cmakedefine NEED_ICONV_TRANSLIT
#cmakedefine QORE_RUNTIME_THREAD_STACK_TRACE


#cmakedefine ZONEINFO_LOCATION "@ZONEINFO_LOCATION@"

#ifndef PACKAGE_VERSION
#define PACKAGE_VERSION "@VERSION@"
#endif
#ifndef VERSION
#define VERSION "@VERSION@"
#endif
#define VERSION_MAJOR @VERSION_MAJOR@
#define VERSION_MINOR @VERSION_MINOR@
#define VERSION_SUB @VERSION_SUB@
#define VERSION_PATCH @VERSION_PATCH@


#define TARGET_OS "@CMAKE_SYSTEM_NAME@"
#define TARGET_ARCH "@CMAKE_SYSTEM_PROCESSOR@"
#define TARGET_BITS @TARGET_BITS@
#define QORE_BUILD_HOST "@QORE_BUILD_HOST@"

#define QORE_LIB_CXX "@CMAKE_CXX_COMPILER_ID@"

/* to be set later */
#define QORE_LIB_CFLAGS "@CMAKE_CXX_FLAGS@"
#define QORE_LIB_LDFLAGS "@CMAKE_LDFLAGS@"

==> qore-2.0.0.tar.bz2: qore-2.0.0/cmake/unix-config.h.cmake <==


/* headers */
#cmakedefine HAVE_ARPA_INET_H
#cmakedefine HAVE_CXXABI_H
#cmakedefine HAVE_DLFCN_H
#cmakedefine HAVE_FCNTL_H
#cmakedefine HAVE_GETOPT_H
#cmakedefine HAVE_GLOB_H
#cmakedefine HAVE_GRP_H
#cmakedefine HAVE_ICONV_H
#cmakedefine HAVE_INTTYPES_H
#cmakedefine HAVE_LINUX_IF_PACKET_H
#cmakedefine HAVE_MEMORY_H
#cmakedefine HAVE_NETDB_H
#cmakedefine HAVE_NETINET_IN_H
#cmakedefine HAVE_NETINET_TCP_H
#cmakedefine HAVE_NET_IF_DL_H
#cmakedefine HAVE_POLL_H
#cmakedefine HAVE_PWD_H
#cmakedefine HAVE_STDBOOL_H
#cmakedefine HAVE_STDDEF_H
#cmakedefine HAVE_STDINT_H
#cmakedefine HAVE_STDLIB_H
#cmakedefine HAVE_STRINGS_H
#cmakedefine HAVE_STRING_H
#cmakedefine HAVE_SYS_SELECT_H
#cmakedefine HAVE_SYS_SOCKET_H
#cmakedefine HAVE_SYS_STATVFS_H
#cmakedefine HAVE_SYS_STAT_H
#cmakedefine HAVE_SYS_TIME_H
#cmakedefine HAVE_SYS_TYPES_H
#cmakedefine HAVE_SYS_UN_H
#cmakedefine HAVE_SYS_WAIT_H
#cmakedefine HAVE_TERMIOS_H
#cmakedefine HAVE_UMEM_H
#cmakedefine HAVE_UNISTD_H
#cmakedefine HAVE_VFORK_H
#cmakedefine HAVE_WINSOCK2_H
#cmakedefine HAVE_WS2TCPIP_H

/* functions */
#cmakedefine HAVE_ACCESS
#cmakedefine HAVE_ALARM
#cmakedefine HAVE_ATOLL
#cmakedefine HAVE_BZERO
#cmakedefine HAVE_CHOWN
#cmakedefine HAVE_CLOCK_GETTIME
#cmakedefine HAVE_DECL_STRERROR_R
#cmakedefine HAVE_DOPRNT
#cmakedefine HAVE_EXP2
#cmakedefine HAVE_FLOOR
#cmakedefine HAVE_FORK
#cmakedefine HAVE_FSYNC
#cmakedefine HAVE_GETEGID
#cmakedefine HAVE_GETEUID
#cmakedefine HAVE_GETGID
#cmakedefine HAVE_GETGRGID_R
#cmakedefine HAVE_GETGRNAM_R
#cmakedefine HAVE_GETGROUPS
#cmakedefine HAVE_GETHOSTBYADDR
#cmakedefine HAVE_GETHOSTBYADDR_R
#cmakedefine HAVE_GETHOSTBYNAME_R
#cmakedefine HAVE_GETHOSTBYNAME
#cmakedefine HAVE_GETHOSTNAME
#cmakedefine HAVE_GETPPID
#cmakedefine HAVE_GETPWNAM_R
#cmakedefine HAVE_GETPWUID_R
#cmakedefine HAVE_GETRLIMIT
#cmakedefine HAVE_GETSOCKOPT
#cmakedefine HAVE_GETTIMEOFDAY
#cmakedefine HAVE_GETUID
#cmakedefine HAVE_GLOB
#cmakedefine HAVE_GMTIME_R
#cmakedefine HAVE_INET_NTOP
#cmakedefine HAVE_INET_PTON
#cmakedefine HAVE_ISBLANK
#cmakedefine HAVE_KILL
#cmakedefine HAVE_LCHOWN
#cmakedefine HAVE_LINK_NTOA
#cmakedefine HAVE_LOCALTIME_R
#cmakedefine HAVE_LSTAT
#cmakedefine HAVE_MEMMEM
#cmakedefine HAVE_MEMMOVE
#cmakedefine HAVE_MEMSET
#cmakedefine HAVE_MKFIFO
#cmakedefine HAVE_MKFIFO
#cmakedefine HAVE_NANOSLEEP
#cmakedefine HAVE_POLL
#cmakedefine HAVE_PTHREAD_ATTR_GETSTACKSIZE
#cmakedefine QORE_HAVE_PTHREAD_SETNAME_NP_1
#cmakedefine QORE_HAVE_PTHREAD_SETNAME_NP_2
#cmakedefine QORE_HAVE_PTHREAD_SETNAME_NP_3
#cmakedefine QORE_HAVE_PTHREAD_SET_NAME_NP
#cmakedefine QORE_HAVE_PTHREAD_GETATTR_NP
#cmakedefine HAVE_PTHREAD_GETNAME_NP
#cmakedefine HAVE_PUTENV
#cmakedefine HAVE_RANDOM
#cmakedefine HAVE_READLINK
#cmakedefine HAVE_REALLOC
#cmakedefine HAVE_REALPATH
#cmakedefine HAVE_REGCOMP
#cmakedefine HAVE_ROUND
#cmakedefine HAVE_SELECT
#cmakedefine HAVE_SETEGID
#cmakedefine HAVE_SETEGID
#cmakedefine HAVE_SETENV
#cmakedefine HAVE_SETEUID
#cmakedefine HAVE_SETEUID
#cmakedefine HAVE_SETGID
#cmakedefine HAVE_SETGROUPS
#cmakedefine HAVE_SETSID
#cmakedefine HAVE_SETSOCKOPT
#cmakedefine HAVE_SETUID
#cmakedefine HAVE_SETUID
#cmakedefine HAVE_SLEEP
#cmakedefine HAVE_SOCKET
#cmakedefine HAVE_STRCASECMP
#cmakedefine HAVE_STRCASESTR
#cmakedefine HAVE_STRCHR
#cmakedefine HAVE_STRDUP
#cmakedefine HAVE_STRERROR
#cmakedefine HAVE_STRERROR_R
#cmakedefine HAVE_STRNCASECMP
#cmakedefine HAVE_STRSPN
#cmakedefine HAVE_STRSTR
#cmakedefine HAVE_STRTOIMAX
#cmakedefine HAVE_STRTOL
#cmakedefine HAVE_STRTOLL
#cmakedefine HAVE_SYMLINK
#cmakedefine HAVE_SYSTEM
#cmakedefine HAVE_TBBMALLOC
#cmakedefine HAVE_TIMEGM
#cmakedefine HAVE_UNSETENV
#cmakedefine HAVE_USLEEP
#cmakedefine HAVE_VFORK
#cmakedefine HAVE_VPRINTF
#cmakedefine HAVE_PTHREAD_GET_STACKSIZE_NP
#cmakedefine HAVE_GETIFADDRS
#cmakedefine HAVE_WORKING_FORK
#cmakedefine HAVE_WORKING_VFORK
#cmakedefine STRERROR_R_CHAR_P

/* OpenSSL */
#cmakedefine HAVE_OPENSSL_CONST
#cmakedefine HAVE_OPENSSL_HMAC_RV
#cmakedefine HAVE_OPENSSL_SHA512
#cmakedefine HAVE_OPENSSL_SHA
#cmakedefine HAVE_OPENSSL_MDC2
#cmakedefine NEED_SSL_CTX_NEW_CONST
#cmakedefine HAVE_X509_GET_SIGNATURE_NID
#cmakedefine HAVE_X509_GET0_SIGNATURE_CONST
#cmakedefine HAVE_X509_GET0_PUBKEY
#cmakedefine HAVE_OPENSSL_INIT_CRYPTO
#cmakedefine HAVE_SSL_SET_MAX_PROTO_VERSION
#cmakedefine HAVE_SSL_SET_HOSTFLAGS
#cmakedefine HAVE_SSL_SET1_HOST
#cmakedefine HAVE_EVP_MAC_CTX_NEW
#cmakedefine HAVE_SSL_READ_EX
#cmakedefine HAVE_OPENSSL_ENGINE_H

/* mpfr */
#cmakedefine HAVE_MPFR_BUILDOPT_TLS_P
#cmakedefine HAVE_MPFR_DIVBY0
#cmakedefine HAVE_MPFR_EXP_T
#cmakedefine HAVE_MPFR_REGULAR
#cmakedefine HAVE_MPFR_RNDN
#cmakedefine HAVE_MPFR_SPRINTF
#cmakedefine HAVE_RNDN

/* backtrace */
#cmakedefine Backtrace_FOUND
#ifdef Backtrace_FOUND
#define HAVE_EXECINFO_H
#define HAVE_BACKTRACE
#endif

/* gethost* */
#cmakedefine HAVE_DECL_GETHOSTBYADDR_R
#cmakedefine HAVE_DECL_GETHOSTBYNAME_R
#cmakedefine HAVE_GETHOSTBYNAME_R_GLIBC2_STYLE
#cmakedefine HAVE_GETHOSTBYNAME_R_RETURN_INT
#cmakedefine HAVE_SOLARIS_STYLE_GETHOST

/* stl hash_map and list */
#cmakedefine HASH_MAP_INCLUDE @HASH_MAP_INCLUDE@
#cmakedefine HASH_NAMESPACE @HASH_NAMESPACE@
#cmakedefine HASH_SET_INCLUDE @HASH_SET_INCLUDE@
#cmakedefine HASH_TYPE @HASH_TYPE@
#cmakedefine HAVE_EXT_HASH_MAP
#cmakedefine HAVE_EXT_HASH_SET
#cmakedefine HAVE_EXT_SLIST
#cmakedefine HAVE_HASH_MAP
#cmakedefine HAVE_HASH_SET
#cmakedefine HAVE_QORE_HASH_MAP
#cmakedefine HAVE_QORE_SLIST
#cmakedefine HAVE_SLIST
#cmakedefine HAVE_UNORDERED_MAP
#cmakedefine LIST_NAMESPACE @LIST_NAMESPACE@
#cmakedefine LIST_SET_INCLUDE @LIST_SET_INCLUDE@
#cmakedefine SLIST_INCLUDE @SLIST_INCLUDE@
#cmakedefine SLIST_TYPE @SLIST_TYPE@

/* CPUs */
#cmakedefine CPU_X86_64
#cmakedefine SPARC

/* OSes */
#cmakedefine DARWIN
#cmakedefine HPUX
#cmakedefine SOLARIS

/* the rest */
#cmakedefine HAVE_ATOMIC_COMPILE_ONLY
#cmakedefine HAVE_CXX11
#cmakedefine HAVE_GCC_VISIBILITY
#cmakedefine HAVE_LIBATOMIC
#cmakedefine HAVE_LLVM_BUG_22050
#cmakedefine HAVE_LOCAL_VARIADIC_ARRAYS
#cmakedefine HAVE_LSTAT_EMPTY_STRING_BUG
#cmakedefine HAVE_NAMESPACES
#cmakedefine HAVE_PTHREAD
#cmakedefine HAVE_SIGNAL_HANDLING
#cmakedefine HAVE_STAT_EMPTY_STRING_BUG
#cmakedefine HAVE_STRUCT_FLOCK
#cmakedefine HAVE_STRUCT_STAT_ST_BLKSIZE
#cmakedefine HAVE_STRUCT_STAT_ST_BLOCKS
#cmakedefine HAVE_STRUCT_STAT_ST_RDEV
#cmakedefine HAVE_ST_BLOCKS
#cmakedefine NEED_DLFCN_WRAPPER
#cmakedefine NEED_ICONV_TRANSLIT
#cmakedefine QORE_RUNTIME_THREAD_STACK_TRACE


#cmakedefine ZONEINFO_LOCATION "@ZONEINFO_LOCATION@"

#ifndef PACKAGE_VERSION
#define PACKAGE_VERSION "@VERSION@"
#endif
#ifndef VERSION
#define VERSION "@VERSION@"
#endif
#define VERSION_MAJOR @VERSION_MAJOR@
#define VERSION_MINOR @VERSION_MINOR@
#define VERSION_SUB @VERSION_SUB@
#define VERSION_PATCH @VERSION_PATCH@


#define TARGET_OS "@CMAKE_SYSTEM_NAME@"
#define TARGET_ARCH "@CMAKE_SYSTEM_PROCESSOR@"
#define TARGET_BITS @TARGET_BITS@
#define QORE_BUILD_HOST "@QORE_BUILD_HOST@"

#define QORE_LIB_CXX "@CMAKE_CXX_COMPILER_ID@"

/* to be set later */
#define QORE_LIB_CFLAGS "@CMAKE_CXX_FLAGS@"
#define QORE_LIB_LDFLAGS "@CMAKE_LDFLAGS@"
